@@ -144,30 +144,37 @@ class Physics(_control.Physics):
     """
     np.copyto(self.data.ctrl, control)
 
-  def step(self, nstep=1):
-    """Advances physics with up-to-date position and velocity dependent fields.
-
-    Args:
-      nstep: Optional integer, number of steps to take.
-
-    The actuation can be updated by calling the `set_control` function first.
-    """
+  def _step_with_up_to_date_position_velocity(self, nstep: int = 1) -> None:
+    """Physics step with up-to-date position and velocity dependent fields."""
     # In the case of Euler integration we assume mj_step1 has already been
     # called for this state, finish the step with mj_step2 and then update all
     # position and velocity related fields with mj_step1. This ensures that
     # (most of) mjData is in sync with qpos and qvel. In the case of non-Euler
     # integrators (e.g. RK4) an additional mj_step1 must be called after the
     # last mj_step to ensure mjData syncing.
+    if self.model.opt.integrator != mujoco.mjtIntegrator.mjINT_RK4.value:
+      mujoco.mj_step2(self.model.ptr, self.data.ptr)
+      if nstep > 1:
+        mujoco.mj_step(self.model.ptr, self.data.ptr, nstep-1)
+    else:
+      mujoco.mj_step(self.model.ptr, self.data.ptr, nstep)
+
+    mujoco.mj_step1(self.model.ptr, self.data.ptr)
+
+  def step(self, nstep: int = 1) -> None:
+    """Advances the physics state by `nstep`s.
+
+    Args:
+      nstep: Optional integer, number of steps to take.
+
+    The actuation can be updated by calling the `set_control` function first.
+    """
     with self.check_invalid_state():
-      if self.model.opt.integrator != mujoco.mjtIntegrator.mjINT_RK4.value:
-        mujoco.mj_step2(self.model.ptr, self.data.ptr)
-        if nstep > 1:
-          mujoco.mj_step(self.model.ptr, self.data.ptr, nstep-1)
+      if self.legacy_step:
+        self._step_with_up_to_date_position_velocity(nstep)
       else:
         mujoco.mj_step(self.model.ptr, self.data.ptr, nstep)
 
-      mujoco.mj_step1(self.model.ptr, self.data.ptr)
-
   def render(
       self,
       height=240,
