@@ -23,6 +23,7 @@ from dm_control.mujoco import index
 from dm_control.mujoco import wrapper
 from dm_control.mujoco.testing import assets
 from dm_control.mujoco.wrapper.mjbindings import sizes
+import mujoco
 import numpy as np
 
 MODEL = assets.get_contents('cartpole.xml')
@@ -58,6 +59,7 @@ class MujocoIndexTest(parameterized.TestCase):
     super().setUp()
     self._model = wrapper.MjModel.from_xml_string(MODEL)
     self._data = wrapper.MjData(self._model)
+    mujoco.mj_forward(self._model.ptr, self._data.ptr)
 
     self._size_to_axis_indexer = index.make_axis_indexers(self._model)
 
@@ -285,8 +287,8 @@ class MujocoIndexTest(parameterized.TestCase):
     index.struct_indexer(data, 'mjdata', size_to_axis_indexer)
 
   # pylint: disable=undefined-variable
-  @parameterized.parameters([
-      name for name in dir(np.ndarray)
+  @parameterized.named_parameters([
+      (name, name) for name in dir(np.ndarray)
       if not name.startswith('_')  # Exclude 'private' attributes
       and name not in ('ctypes', 'flat')  # Can't compare via identity/equality
   ])
@@ -312,6 +314,7 @@ class MujocoIndexTest(parameterized.TestCase):
 
 
 def _iter_indexers(model, data):
+  mujoco.mj_forward(model.ptr, data.ptr)
   size_to_axis_indexer = index.make_axis_indexers(model)
   all_fields = collections.OrderedDict()
   for struct, struct_name in ((model, 'mjmodel'), (data, 'mjdata')):
